==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/vi.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Tài liệu",
"Can't create document" => "Không thể tạo tài liệu",
"You don't have permission to rename this document" => "Bạn không có quyền đổi tên tài liệu này",
"Saved" => "Đã lưu",
"Saving..." => "Đang lưu...",
"Failed to load documents." => "Không thể tải tài liệu thử lại sau.",
"No connection to server. Trying to reconnect." => "Không thể kết nối đến máy chủ. Đang thử kết nối lại.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Rời khỏi trang này khi đang trong chế độ chỉnh sửa có thể gây mất dữ liệu. Bạn nên sử dụng nút 'Đóng' để thay thế.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Không thể tải tài liệu này. Hãy kiểm tra xem nó có thể đang được mở ra bởi ai đó. Hay là tài liệu này không  chia sẻ hoặc bị xóa gần đây.",
"Save" => "Lưu",
"Loading documents..." => "Tải tài liệu ...",
"'.' is an invalid file name." => "'.' là một tên file không hợp lệ",
"File name cannot be empty." => "Tên file không được rỗng",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Tên không hợp lệ, '\\', '/', '<', '>', ':', '\"', '|', '?' và '*' thì không được phép dùng.",
"Align Left" => "Canh trái",
"Alignment" => "Canh giữa",
"Align Right" => "Canh phải",
"Annotate" => "Chú thích",
"Background" => "Nền",
"Bold" => "In đậm",
"Bottom" => "Ở dưới",
"Cancel" => "Hủy",
"Center" => "Ở giữa",
"Clone" => "Sao chép",
"Clone this Style" => "Sao chép kiểu này",
"Close" => "Đóng",
"Color" => "Màu sắc",
"Create" => "Tạo",
"Decrease Indent" => "Giảm thụt lề",
"Default Style" => "Kiểu mặc định",
"Delete" => "Xóa",
"Family" => "Gia đình",
"Font" => "Font chữ",
"Font Effects" => "Hiệu ứng chữ",
"Format" => "Định dạng",
"Increase Indent" => "Tăng thụt lề",
"Insert Image" => "Chèn ảnh",
"Invite Members" => "Mời thành viên",
"Italic" => "in nghiêng",
"Justified" => "Canh đều",
"Justify" => "Căn chỉnh",
"Left" => "Bên trái",
"Loading" => "Đang tải",
"Members" => "Thành viên",
"New Name:" => "Tên mới:",
"OK" => "Chấp nhận",
"Open" => "Mở",
"Options" => "Tùy chọn",
"Paragraph..." => "Đoạn văn bản...",
"Paragraph Styles" => "Kiểu đoạn văn bản",
"Redo" => "Làm lại",
"Right" => "Bên phải",
"Size" => "Kích cỡ",
"Spacing" => "Khoảng cách",
"Strikethrough" => "Gạch ngang",
"Style" => "Kiểu",
"Text" => "Văn bản",
"Top" => "Ở trên",
"Underline" => "Gạch chân",
"Undo" => "Lùi lại",
"Unknown Author" => "Không biết tác giả",
"Edit" => "Sửa",
"Share" => "Chia sẻ",
"Disabled" => "Tắt",
"New document" => "Tạo mới",
"Upload" => "Tải lên",
"Save new documents to" => "Lưu tài liệu ",
"Wrong password. Please retry." => "Mật khẩu không đúng. Vui lòng thử lại.",
"Password" => "Mật khẩu",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Liên kết này đã hết hạn hoặc không tồn tại. Vui lòng liên hệ với người đã chia sẻ nó để biết chi tiết.",
"Advanced feature-set" => "Thiết lập tính năng nâng cao",
"(Unstable)" => "(Không ổn định)"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";

==> owncloud-app-documents-1%3A9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/vi.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Tài liệu",
"Can't create document" => "Không thể tạo tài liệu",
"You don't have permission to rename this document" => "Bạn không có quyền đổi tên tài liệu này",
"Saved" => "Đã lưu",
"Saving..." => "Đang lưu...",
"Failed to load documents." => "Không thể tải tài liệu thử lại sau.",
"No connection to server. Trying to reconnect." => "Không thể kết nối đến máy chủ. Đang thử kết nối lại.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Rời khỏi trang này khi đang trong chế độ chỉnh sửa có thể gây mất dữ liệu. Bạn nên sử dụng nút 'Đóng' để thay thế.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Không thể tải tài liệu này. Hãy kiểm tra xem nó có thể đang được mở ra bởi ai đó. Hay là tài liệu này không  chia sẻ hoặc bị xóa gần đây.",
"Save" => "Lưu",
"Loading documents..." => "Tải tài liệu ...",
"'.' is an invalid file name." => "'.' là một tên file không hợp lệ",
"File name cannot be empty." => "Tên file không được rỗng",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Tên không hợp lệ, '\\', '/', '<', '>', ':', '\"', '|', '?' và '*' thì không được phép dùng.",
"Align Left" => "Canh trái",
"Alignment" => "Canh giữa",
"Align Right" => "Canh phải",
"Annotate" => "Chú thích",
"Background" => "Nền",
"Bold" => "In đậm",
"Bottom" => "Ở dưới",
"Cancel" => "Hủy",
"Center" => "Ở giữa",
"Clone" => "Sao chép",
"Clone this Style" => "Sao chép kiểu này",
"Close" => "Đóng",
"Color" => "Màu sắc",
"Create" => "Tạo",
"Decrease Indent" => "Giảm thụt lề",
"Default Style" => "Kiểu mặc định",
"Delete" => "Xóa",
"Family" => "Gia đình",
"Font" => "Font chữ",
"Font Effects" => "Hiệu ứng chữ",
"Format" => "Định dạng",
"Increase Indent" => "Tăng thụt lề",
"Insert Image" => "Chèn ảnh",
"Invite Members" => "Mời thành viên",
"Italic" => "in nghiêng",
"Justified" => "Canh đều",
"Justify" => "Căn chỉnh",
"Left" => "Bên trái",
"Loading" => "Đang tải",
"Members" => "Thành viên",
"New Name:" => "Tên mới:",
"OK" => "Chấp nhận",
"Open" => "Mở",
"Options" => "Tùy chọn",
"Paragraph..." => "Đoạn văn bản...",
"Paragraph Styles" => "Kiểu đoạn văn bản",
"Redo" => "Làm lại",
"Right" => "Bên phải",
"Size" => "Kích cỡ",
"Spacing" => "Khoảng cách",
"Strikethrough" => "Gạch ngang",
"Style" => "Kiểu",
"Text" => "Văn bản",
"Top" => "Ở trên",
"Underline" => "Gạch chân",
"Undo" => "Lùi lại",
"Unknown Author" => "Không biết tác giả",
"Shared" => "Được chia sẻ",
"Error" => "Lỗi",
"Error while sharing" => "Lỗi trong quá trình chia sẻ",
"Error while unsharing" => "Lỗi trong quá trình gỡ chia sẻ",
"Error while changing permissions" => "Lỗi trong quá trình phân quyền",
"Shared with you and the group {group} by {owner}" => "Đã được chia sẽ với bạn và nhóm {group} bởi {owner}",
"Shared with you by {owner}" => "Đã được chia sẽ bởi {owner}",
"Share" => "Chia sẻ",
"Share link" => "Chia sẻ liên kết",
"Password protect" => "Mật khẩu bảo vệ",
"Password" => "Mật khẩu",
"Email link to person" => "Liên kết email tới cá nhân",
"Send" => "Gởi",
"Set expiration date" => "Đặt ngày kết thúc",
"Expiration date" => "Ngày kết thúc",
"group" => "nhóm",
"Resharing is not allowed" => "Chia sẻ lại không được cho phép",
"Shared in {item} with {user}" => "Đã được chia sẽ trong {item} với {user}",
"Unshare" => "Bỏ chia sẻ",
"notify by email" => "Thông báo qua email",
"can share" => "có thể chia sẽ",
"can edit" => "có thể chỉnh sửa",
"access control" => "quản lý truy cập",
"create" => "tạo",
"delete" => "xóa",
"Password protected" => "Mật khẩu bảo vệ",
"Error unsetting expiration date" => "Lỗi không thiết lập ngày kết thúc",
"Error setting expiration date" => "Lỗi cấu hình ngày kết thúc",
"Sending ..." => "Đang gởi ...",
"Email sent" => "Email đã được gửi",
"Warning" => "Cảnh báo",
"Edit" => "Sửa",
"Disabled" => "Tắt",
"New document" => "Tạo mới",
"Upload" => "Tải lên",
"Save new documents to" => "Lưu tài liệu ",
"Wrong password. Please retry." => "Mật khẩu không đúng. Vui lòng thử lại.",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Liên kết này đã hết hạn hoặc không tồn tại. Vui lòng liên hệ với người đã chia sẻ nó để biết chi tiết.",
"Advanced feature-set" => "Thiết lập tính năng nâng cao",
"(Unstable)" => "(Không ổn định)"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
